@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -841,7 +841,7 @@ public class RepairRunIntervalWindow
 		}
 
 		//save it deleting the old first for having the same uniqueID
-		SqliteRun.Delete(Constants.RunIntervalTable, runInterval.UniqueID.ToString());
+		Sqlite.Delete(Constants.RunIntervalTable, runInterval.UniqueID);
 		runInterval.InsertAtDB(false, Constants.RunIntervalTable); 
 		/*
 		SqliteRun.InsertInterval(false, Constants.RunIntervalTable, runInterval.UniqueID.ToString(), 
@@ -926,6 +926,7 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_extra_window_radio_run_interval_by_time;
 	[Widget] Gtk.Label label_extra_window_radio_run_interval_unlimited;
 	[Widget] Gtk.Label label_extra_window_radio_run_interval_mtgug;
+	[Widget] Gtk.Label label_extra_window_radio_run_interval_rsa_test_1;
 	[Widget] Gtk.Label label_extra_window_radio_run_interval_more;
 	
 	//radio notebook_execute	
@@ -933,25 +934,42 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_by_time;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_unlimited;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_mtgug;
+	[Widget] Gtk.RadioButton extra_window_radio_run_interval_rsa_test_1;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_more;
 
 	//options runs
 	[Widget] Gtk.Label extra_window_runs_label_distance;
 	[Widget] Gtk.SpinButton extra_window_runs_spinbutton_distance;
 	[Widget] Gtk.Label extra_window_runs_label_distance_units;
-
 	[Widget] Gtk.Label extra_window_label_runs_no_options;
 	
+	[Widget] Gtk.Box vbox_runs_prevent_double_contact;
+	[Widget] Gtk.CheckButton checkbutton_runs_prevent_double_contact;
+	[Widget] Gtk.SpinButton spinbutton_runs_prevent_double_contact;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_first;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_average;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_last;
+	[Widget] Gtk.RadioButton radio_runs_speed_start_arrival;
+	[Widget] Gtk.RadioButton radio_runs_speed_start_leaving;
+	
 	//options runs interval
 	[Widget] Gtk.Label extra_window_runs_interval_label_distance;
 	[Widget] Gtk.SpinButton extra_window_runs_interval_spinbutton_distance;
 	[Widget] Gtk.Label extra_window_runs_interval_label_distance_units;
-
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit;
 	[Widget] Gtk.SpinButton extra_window_runs_interval_spinbutton_limit;
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit_units;
-
 	[Widget] Gtk.Label extra_window_label_runs_interval_no_options;
+	
+	[Widget] Gtk.Box vbox_runs_i_prevent_double_contact;
+	[Widget] Gtk.CheckButton checkbutton_runs_i_prevent_double_contact;
+	[Widget] Gtk.SpinButton spinbutton_runs_i_prevent_double_contact;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_first;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_average;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_last;
+	[Widget] Gtk.RadioButton radio_runs_i_speed_start_arrival;
+	[Widget] Gtk.RadioButton radio_runs_i_speed_start_leaving;
+	
 
 	//selected test labels	
 	[Widget] Gtk.Label extra_window_runs_label_selected;
@@ -1001,6 +1019,7 @@ partial class ChronoJumpWindow
 		else if(extra_window_radio_run_interval_by_time.Active) currentRunIntervalType = new RunType("byTime");
 		else if(extra_window_radio_run_interval_unlimited.Active) currentRunIntervalType = new RunType("unlimited");
 		else if(extra_window_radio_run_interval_mtgug.Active) currentRunIntervalType = new RunType("MTGUG");
+		//else if(extra_window_radio_run_interval_rsa_test_1.Active) currentRunIntervalType = new RunType("RSA 8-4-R3-5");
 
 		extra_window_runs_interval_initialize(currentRunIntervalType);
 	}
@@ -1025,7 +1044,7 @@ partial class ChronoJumpWindow
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
 		bool hasOptions = false;
 
-		extra_window_runs_label_distance.Text = Catalog.GetString("Track distance\n(between platforms)");
+		extra_window_runs_label_distance.Text = Catalog.GetString("Track distance (between platforms)");
 		extra_window_runs_label_distance_units.Text = Catalog.GetString("meters");
 
 		if(myRunType.Distance > 0) {
@@ -1203,6 +1222,7 @@ partial class ChronoJumpWindow
 		else if(type.Name == "byTime") extra_window_radio_run_interval_by_time.Active = true;
 		else if(type.Name == "unlimited") extra_window_radio_run_interval_unlimited.Active = true;
 		else if(type.Name == "MTGUG") extra_window_radio_run_interval_mtgug.Active = true;
+		//else if(type.Name == "RSA 8-4-R3-5") extra_window_radio_run_interval_rsa_test_1.Active = true;
 		else {
 			//don't do this:
 			//extra_window_radio_run_interval_more.Active = true;
@@ -1249,7 +1269,31 @@ partial class ChronoJumpWindow
 			extra_window_label_runs_no_options.Visible = ! hasOptions;
 	}
 
+	protected void on_checkbutton_runs_prevent_double_contact_toggled (object o, EventArgs args) {
+		vbox_runs_prevent_double_contact.Visible = checkbutton_runs_prevent_double_contact.Active;
+	}
+	protected void on_checkbutton_runs_i_prevent_double_contact_toggled (object o, EventArgs args) {
+		vbox_runs_i_prevent_double_contact.Visible = checkbutton_runs_i_prevent_double_contact.Active;
+	}
 
+
+	bool update_sqlite_at_runs_speed_radios = false;
+	private void on_radio_runs_speed_start_toggled (object o, EventArgs args) {
+		if(update_sqlite_at_runs_speed_radios) {
+			if(radio_runs_speed_start_arrival.Active)
+				SqlitePreferences.Update("runSpeedStartArrival", "True", false);
+			else
+				SqlitePreferences.Update("runSpeedStartArrival", "False", false);
+		}
+	}
+	private void on_radio_runs_i_speed_start_toggled (object o, EventArgs args) {
+		if(update_sqlite_at_runs_speed_radios) {
+			if(radio_runs_i_speed_start_arrival.Active)
+				SqlitePreferences.Update("runISpeedStartArrival", "True", false);
+			else
+				SqlitePreferences.Update("runISpeedStartArrival", "False", false);
+		}
+	}
 }
 
 
